@@ -34,13 +34,13 @@
 #include <tqhgroupbox.h>
 
 #include <kbookmarkmanager.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
-#include <kio/previewjob.h>
-#include <kfileitem.h>
+#include <tdeio/previewjob.h>
+#include <tdefileitem.h>
 #include <kdialog.h>
-#include <kglobalsettings.h>
-#include <kfilemetainfo.h>
+#include <tdeglobalsettings.h>
+#include <tdefilemetainfo.h>
 
 #include "dolphin.h"
 #include "pixmapviewer.h"
@@ -68,8 +68,8 @@ InfoSidebarPage::InfoSidebarPage(TQWidget* parent) :
 
     // preview
     m_preview = new PixmapViewer(this);
-    m_preview->setMinimumWidth(KIcon::SizeEnormous);
-    m_preview->setFixedHeight(KIcon::SizeEnormous);
+    m_preview->setMinimumWidth(TDEIcon::SizeEnormous);
+    m_preview->setFixedHeight(TDEIcon::SizeEnormous);
 
     // name
     m_name = new TQLabel(this);
@@ -155,10 +155,10 @@ void InfoSidebarPage::showItemInfo()
     }
 
     if (m_multipleSelection) {
-        KIconLoader iconLoader;
-        TQPixmap icon = iconLoader.loadIcon("exec",
-                                           KIcon::NoGroup,
-                                           KIcon::SizeEnormous);
+        TDEIconLoader iconLoader;
+        TQPixmap icon = iconLoader.loadIcon("application-x-executable",
+                                           TDEIcon::NoGroup,
+                                           TDEIcon::SizeEnormous);
         m_preview->setPixmap(icon);
         m_name->setText(i18n("%n items selected", "%n items selected", selectedItems->count()));
     }
@@ -170,9 +170,9 @@ void InfoSidebarPage::showItemInfo()
         m_pendingPreview = true;
         m_preview->setPixmap(TQPixmap());
 
-        KIO::PreviewJob* job = KIO::filePreview(list,
+        TDEIO::PreviewJob* job = TDEIO::filePreview(list,
                                                 m_preview->width(),
-                                                KIcon::SizeEnormous);
+                                                TDEIcon::SizeEnormous);
         connect(job, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
                 this, TQT_SLOT(gotPreview(const KFileItem*, const TQPixmap&)));
         connect(job, TQT_SIGNAL(failed(const KFileItem*)),
@@ -198,7 +198,7 @@ void InfoSidebarPage::slotPreviewFailed(const KFileItem* item)
 {
     m_pendingPreview = false;
     if (!applyBookmark()) {
-        m_preview->setPixmap(item->pixmap(KIcon::SizeEnormous));
+        m_preview->setPixmap(item->pixmap(TDEIcon::SizeEnormous));
     }
 }
 
@@ -248,10 +248,10 @@ bool InfoSidebarPage::applyBookmark()
             text.append("</b>");
             m_name->setText(text);
 
-            KIconLoader iconLoader;
+            TDEIconLoader iconLoader;
             TQPixmap icon = iconLoader.loadIcon(bookmark.icon(),
-                                               KIcon::NoGroup,
-                                               KIcon::SizeEnormous);
+                                               TDEIcon::NoGroup,
+                                               TDEIcon::SizeEnormous);
             m_preview->setPixmap(icon);
             return true;
         }
@@ -285,7 +285,7 @@ void InfoSidebarPage::createMetaInfo()
         else {
             addInfoLine(i18n("Type:"), fileItem.mimeComment());
 
-            TQString sizeText(KIO::convertSize(fileItem.size()));
+            TQString sizeText(TDEIO::convertSize(fileItem.size()));
             addInfoLine(i18n("Size:"), sizeText);
             addInfoLine(i18n("Modified:"), fileItem.timeString());
 
@@ -435,7 +435,7 @@ void InfoSidebarPage::insertActions()
     // 'itemList' contains now all KFileItems, where an item information should be shown.
     // TODO: the following algorithm is quite equal to DolphinContextMenu::insertActionItems().
     // It's open yet whether they should be merged or whether they have to work slightly different.
-    TQStringList dirs = KGlobal::dirs()->findDirs("data", "d3lphin/servicemenus/");
+    TQStringList dirs = TDEGlobal::dirs()->findDirs("data", "d3lphin/servicemenus/");
     for (TQStringList::ConstIterator dirIt = dirs.begin(); dirIt != dirs.end(); ++dirIt) {
         TQDir dir(*dirIt);
         TQStringList entries = dir.entryList("*.desktop", TQDir::Files);
@@ -443,8 +443,8 @@ void InfoSidebarPage::insertActions()
         for (TQStringList::ConstIterator entryIt = entries.begin(); entryIt != entries.end(); ++entryIt) {
             KSimpleConfig cfg(*dirIt + *entryIt, true);
             cfg.setDesktopGroup();
-            if ((cfg.hasKey("Actions") || cfg.hasKey("X-KDE-GetActionMenu")) && cfg.hasKey("ServiceTypes")) {
-                const TQStringList types = cfg.readListEntry("ServiceTypes");
+            if ((cfg.hasKey("Actions") || cfg.hasKey("X-TDE-GetActionMenu")) && cfg.hasKey("X-TDE-ServiceTypes")) {
+                const TQStringList types = cfg.readListEntry("X-TDE-ServiceTypes");
                 for (TQStringList::ConstIterator it = types.begin(); it != types.end(); ++it) {
                     // check whether the mime type is equal or whether the
                     // mimegroup (e. g. image/*) is supported
@@ -481,7 +481,7 @@ void InfoSidebarPage::insertActions()
                     }
 
                     if (insert) {
-                        const TQString submenuName = cfg.readEntry( "X-KDE-Submenu" );
+                        const TQString submenuName = cfg.readEntry( "X-TDE-Submenu" );
                         TQPopupMenu* popup = 0;
                         if (!submenuName.isEmpty()) {
                             // create a sub menu containing all actions
@@ -553,12 +553,12 @@ void ServiceButton::drawButton(TQPainter* painter)
     TQColor backgroundColor;
     TQColor foregroundColor;
     if (m_hover) {
-        backgroundColor = KGlobalSettings::highlightColor();
-        foregroundColor = KGlobalSettings::highlightedTextColor();
+        backgroundColor = TDEGlobalSettings::highlightColor();
+        foregroundColor = TDEGlobalSettings::highlightedTextColor();
     }
     else {
         backgroundColor = colorGroup().background();
-        foregroundColor = KGlobalSettings::buttonTextColor();
+        foregroundColor = TDEGlobalSettings::buttonTextColor();
     }
 
     // draw button background
@@ -570,12 +570,12 @@ void ServiceButton::drawButton(TQPainter* painter)
 
     // draw icon
     int x = spacing;
-    const int y = (buttonHeight - KIcon::SizeSmall) / 2;
+    const int y = (buttonHeight - TDEIcon::SizeSmall) / 2;
     const TQIconSet* set = iconSet();
     if (set != 0) {
         painter->drawPixmap(x, y, set->pixmap(TQIconSet::Small, TQIconSet::Normal));
     }
-    x += KIcon::SizeSmall + spacing;
+    x += TDEIcon::SizeSmall + spacing;
 
     // draw text
     painter->setPen(foregroundColor);
